@@ -45,11 +45,6 @@ template<typename T> class SortableList;
 typedef SortableList<QDate> DateList;
 }
 
-namespace KHolidays {
-class HolidayRegion;
-typedef QSharedPointer<HolidayRegion> HolidayRegionPtr;
-}
-
 namespace CalendarSupport {
 class CollectionSelection;
 class KCalPrefs;
@@ -91,7 +86,7 @@ class EVENTVIEWS_EXPORT EventView : public QWidget
 public:
     enum {
         // This value is passed to QColor's lighter(int factor) for selected events
-        BRIGHTNESS_FACTOR = 125
+        BRIGHTNESS_FACTOR = 110
     };
 
     enum ItemIcon {
@@ -148,10 +143,10 @@ public:
       update config is called after prefs are set.
     */
     virtual void setPreferences(const PrefsPtr &preferences);
-    PrefsPtr preferences() const;
+    Q_REQUIRED_RESULT PrefsPtr preferences() const;
 
     virtual void setKCalPreferences(const KCalPrefsPtr &preferences);
-    KCalPrefsPtr kcalPreferences() const;
+    Q_REQUIRED_RESULT KCalPrefsPtr kcalPreferences() const;
 
     /**
       @return a list of selected events. Most views can probably only
@@ -179,13 +174,19 @@ public:
      */
     virtual QDateTime selectionEnd() const;
 
+    /**
+      Sets the default start/end date/time for new events.
+      Return true if anything was changed
+    */
+    virtual bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const;
+
     /**
       Returns whether or not date range selection is enabled. This setting only
       applies to views that actually supports selecting cells.
       @see selectionStart()
       @see selectionEnd()
      */
-    bool dateRangeSelectionEnabled() const;
+    Q_REQUIRED_RESULT bool dateRangeSelectionEnabled() const;
 
     /**
       Enable or disable date range selection.
@@ -209,7 +210,7 @@ public:
 
     virtual void showConfigurationDialog(QWidget *parent);
 
-    QByteArray identifier() const;
+    Q_REQUIRED_RESULT QByteArray identifier() const;
     void setIdentifier(const QByteArray &identifier);
 
     /**
@@ -236,7 +237,7 @@ public:
       each AgendaView displays only one collection.
     */
     void setCollectionId(Akonadi::Collection::Id id);
-    Akonadi::Collection::Id collectionId() const;
+    Q_REQUIRED_RESULT Akonadi::Collection::Id collectionId() const;
 
     //----------------------------------------------------------------------------
     KCheckableProxyModel *takeCustomCollectionSelectionProxyModel();
@@ -261,21 +262,20 @@ public:
      * month to show when the week crosses months.  It's a QDate instead
      * of uint so it can be easily fed to KCalendarSystem's functions.
      */
-    virtual void setDateRange(const QDateTime &start, const QDateTime &end,
-                              const QDate &preferredMonth = QDate());
+    virtual void setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate());
 
-    QDateTime startDateTime() const;
-    QDateTime endDateTime() const;
+    Q_REQUIRED_RESULT QDateTime startDateTime() const;
+    Q_REQUIRED_RESULT QDateTime endDateTime() const;
 
-    QDateTime actualStartDateTime() const;
-    QDateTime actualEndDateTime() const;
+    Q_REQUIRED_RESULT QDateTime actualStartDateTime() const;
+    Q_REQUIRED_RESULT QDateTime actualEndDateTime() const;
 
-    int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
+    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
 
     /**
       Handles key events, opens the new event dialog when enter is pressed, activates type ahead.
     */
-    bool processKeyEvent(QKeyEvent *);
+    Q_REQUIRED_RESULT bool processKeyEvent(QKeyEvent *);
 
     /*
      * Sets the QObject that will receive key events that were made
@@ -298,15 +298,15 @@ public:
     /**
       Returns if there are pending changes and a redraw is needed.
     */
-    Changes changes() const;
+    Q_REQUIRED_RESULT Changes changes() const;
 
     /**
      * Returns a variation of @p color that will be used for the border
      * of an agenda or month item.
      */
-    static QColor itemFrameColor(const QColor &color, bool selected);
+    Q_REQUIRED_RESULT static QColor itemFrameColor(const QColor &color, bool selected);
 
-    QString iconForItem(const Akonadi::Item &);
+    Q_REQUIRED_RESULT QString iconForItem(const Akonadi::Item &);
 
 public Q_SLOTS:
     /**
@@ -346,12 +346,6 @@ public Q_SLOTS:
     */
     virtual void clearSelection();
 
-    /**
-      Sets the default start/end date/time for new events.
-      Return true if anything was changed
-    */
-    virtual bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const;
-
     void focusChanged(QWidget *, QWidget *);
 
     /**
@@ -361,10 +355,10 @@ public Q_SLOTS:
     void defaultAction(const Akonadi::Item &incidence);
 
     /**
-       Set which holidays the user wants to use.
-       @param holidayRegion a HolidayRegion object initialized with the desired locale.
+       Set which holiday regions the user wants to use.
+       @param regions a list of Holiday Regions strings.
     */
-    void setHolidayRegion(const KHolidays::HolidayRegionPtr &holidayRegion);
+    void setHolidayRegions(const QStringList &regions);
 
 Q_SIGNALS:
     /**
@@ -496,8 +490,7 @@ protected:
     /**
       @deprecated
      */
-    virtual void showDates(const QDate &start, const QDate &end,
-                           const QDate &preferredMonth = QDate()) = 0;
+    virtual void showDates(const QDate &start, const QDate &end, const QDate &preferredMonth = QDate()) = 0;
 
     /**
      * from the requested date range (passed via setDateRange()), calculates the
